@@ -13,9 +13,6 @@
 /* Compile for 'real' NVIDIA GPU architectures */
 #define CUDA_ARCH_BIN ""
 
-/* Create PTX or BIN for 1.0 compute capability */
-/* #undef CUDA_ARCH_BIN_OR_PTX_10 */
-
 /* NVIDIA GPU features are used */
 #define CUDA_ARCH_FEATURES ""
 
@@ -31,9 +28,6 @@
 /* Clp support */
 /* #undef HAVE_CLP */
 
-/* Cocoa API */
-/* #undef HAVE_COCOA */
-
 /* NVIDIA CUDA Runtime API*/
 /* #undef HAVE_CUDA */
 
@@ -59,17 +53,11 @@
 /* Geospatial Data Abstraction Library */
 /* #undef HAVE_GDAL */
 
-/* GTK+ 2.0 Thread support */
-/* #undef HAVE_GTHREAD */
-
-/* GTK+ 2.x toolkit */
-/* #undef HAVE_GTK */
-
 /* Halide support */
 /* #undef HAVE_HALIDE */
 
 /* Vulkan support */
-/* #undef HAVE_VULKAN */
+#define HAVE_VULKAN
 
 /* Define to 1 if you have the <inttypes.h> header file. */
 /* #undef HAVE_INTTYPES_H */
@@ -81,7 +69,11 @@
 /* #undef HAVE_IPP_IW_LL */
 
 /* JPEG-2000 codec */
-#define HAVE_JASPER
+#define HAVE_OPENJPEG
+/* #undef HAVE_JASPER */
+
+/* AVIF codec */
+/* #undef HAVE_AVIF */
 
 /* IJG JPEG codec */
 #define HAVE_JPEG
@@ -94,6 +86,8 @@
 
 /* NVIDIA Video Decoding API*/
 /* #undef HAVE_NVCUVID */
+/* #undef HAVE_NVCUVID_HEADER */
+/* #undef HAVE_DYNLINK_NVCUVID_HEADER */
 
 /* NVIDIA Video Encoding API*/
 /* #undef HAVE_NVCUVENC */
@@ -115,18 +109,15 @@
 /* PNG codec */
 #define HAVE_PNG
 
+/* PNG codec */
+/* #undef HAVE_SPNG */
+
 /* Posix threads (pthreads) */
 #define HAVE_PTHREAD
 
 /* parallel_for with pthreads */
 #define HAVE_PTHREADS_PF
 
-/* Qt support */
-#define HAVE_QT
-
-/* Qt OpenGL support */
-#define HAVE_QT_OPENGL
-
 /* Intel Threading Building Blocks */
 #define HAVE_TBB
 
@@ -136,9 +127,6 @@
 /* TIFF codec */
 #define HAVE_TIFF
 
-/* Win32 UI */
-/* #undef HAVE_WIN32UI */
-
 /* Define if your processor stores words with the most significant byte
    first (like Motorola and SPARC, unlike Intel and VAX). */
 /* #undef WORDS_BIGENDIAN */
